@@ -40,12 +40,15 @@ class SkyhubController:
         url = f"{self.base_url}/{produto.sku}"
         
         response = await self.request.request(method="PUT", url=url, data=produtoJSON, headers=self.credentials)
+        print(response.status)
 
         if response.status == 204:
             logger.info(f"O produto '{produto.sku}' foi atualizado.")
             return True
+        
+        if response.status == 429:
+            response = await self.request.request(method="PUT", url=url, data=produtoJSON, headers=self.credentials)
 
         else:
-            print(response.text)
             logger.warning(f"O produto '{produto.sku}' não pode ser atualizado.")
             return False
